permission.templatetags package
===============================

Submodules
----------

permission.templatetags.patch module
------------------------------------

.. automodule:: permission.templatetags.patch
    :members:
    :undoc-members:
    :show-inheritance:

permission.templatetags.permissionif module
-------------------------------------------

.. automodule:: permission.templatetags.permissionif
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.templatetags
    :members:
    :undoc-members:
    :show-inheritance:
